/// <reference types="node" />
import { FullDevice } from 'eufy-node-client/src/http/http-response.models';
import { Socket } from 'dgram';
import { CameraController, CameraStreamingDelegate, PrepareStreamCallback, PrepareStreamRequest, SnapshotRequest, SnapshotRequestCallback, SRTPCryptoSuites, StreamingRequest, StreamRequestCallback } from 'homebridge';
import { EufySecurityHomebridgePlatform } from './platform';
import { FfmpegProcess } from './ffmpeg';
declare type SessionInfo = {
    address: string;
    localAddress: string;
    ipv6: boolean;
    videoPort: number;
    videoReturnPort: number;
    videoCryptoSuite: SRTPCryptoSuites;
    videoSRTP: Buffer;
    videoSSRC: number;
    audioPort: number;
    audioReturnPort: number;
    audioCryptoSuite: SRTPCryptoSuites;
    audioSRTP: Buffer;
    audioSSRC: number;
};
declare type ActiveSession = {
    mainProcess?: FfmpegProcess;
    returnProcess?: FfmpegProcess;
    timeout?: NodeJS.Timeout;
    socket?: Socket;
};
export declare class EufyCameraStreamingDelegate implements CameraStreamingDelegate {
    private ffmpegDebugOutput;
    private readonly platform;
    private readonly hap;
    private readonly device;
    private videoProcessor;
    controller?: CameraController;
    pendingSessions: Record<string, SessionInfo>;
    ongoingSessions: Record<string, ActiveSession>;
    videoConfig: {
        forceMax: undefined;
        maxWidth: number;
        maxHeight: number;
        videoFilter: string;
        maxStreams: number;
        maxFPS: number;
        maxBitrate: undefined;
        vcodec: string;
        audio: boolean;
        packetSize: number;
        hflip: undefined;
        additionalCommandline: undefined;
        debug: boolean;
    };
    constructor(platform: EufySecurityHomebridgePlatform, device: FullDevice);
    private determineResolution;
    handleSnapshotRequest(request: SnapshotRequest, callback: SnapshotRequestCallback): void;
    prepareStream(request: PrepareStreamRequest, callback: PrepareStreamCallback): void;
    private startStream;
    stopStream(sessionId: any, callback?: any): void;
    handleStreamRequest(request: StreamingRequest, callback: StreamRequestCallback): void;
}
export {};
//# sourceMappingURL=streaming-delegate.d.ts.map